;;
;; Phil's .emacs
;; philiph@pobox.com
;;
;; Based on Jeff Jones' .emacs and various other sources
;; off the web.
;;
;; Everyone's .emacs rips off someone else's...
;;
;; $Id: .emacs.el,v 1.7 2000/07/12 22:52:08 philip Exp $

;;; Global settings, not specific to any particular mode.

;; A few defaults.  Season to taste.
(setq user-full-name "Joe Emacs User")
(setq user-mail-address "Joe@Some.Com")
(setq mail-host-address "my.mail.server")
(setq my-emacs-dir "~/.emacstuff/")           ;concat this to dir names.

;; keyboard mods not specific to any mode.
(global-set-key [(control h)] 'delete-backward-char) ;backspace, not help!
(global-set-key "\C-cg" 'goto-line)
(global-set-key [home] 'beginning-of-line)    ;not screen
(global-set-key "\e[1~" 'beginning-of-line)   ;not screen
(global-set-key "\eOH" 'beginning-of-line)    ;Needed on remote xterm?
(global-set-key [end] 'end-of-line)           ;inactive by default?
(global-set-key "\e[4~" 'end-of-line)
(global-set-key "\eOF" 'end-of-line)          ;Needed on remote xterm?

(global-set-key [delete] 'delete-char)    ; delete char, don't move cursor.

(global-set-key [(meta control h)] 'backward-kill-word)

(global-set-key [f2] 'other-window)       ;convenient shortcuts.
(global-set-key [f3] 'kill-this-buffer)

(global-unset-key [escape escape])   ;eval-expr gets in my way.
(global-set-key [(control x)(control u)] 'undo)  ;bind to something useful.

(global-set-key [(shift button2)]               ;<shift>-mouse2 to load
		'browse-url-at-mouse)     ;url at point into netscape.


;; Miscellaneous settings
(setq global-font-lock-mode t)            ;font-lock everywhere.
(setq inhibit-startup-message t)          ;don't need it anymore.
(setq transient-mark-mode t)              ;where's that selection?
(setq lpr-command "a2ps")
(setq lpr-switches nil)

(standard-display-european t)             ;disable multibyte support.

;; Set up default editing mode.
(setq default-major-mode 'indented-text-mode)
(defun my-text-hook ()
  "Set up for editing text, my way"
  (interactive)
  (set-fill-column 70)
  (turn-on-auto-fill))
(setq indented-text-mode-hook 'my-text-hook)
(setq-default save-place t)
(toggle-text-mode-auto-fill)       ;always auto-fill in text mode.Mein fuehrer!!

;; Put all my stuff in my-emacs-dir
(setq load-path (cons my-emacs-dir load-path))


;; Some window system only settings.
(cond (window-system
       (display-time)
       (setq line-number-mode t)
       (setq column-number-mode t)
))

;; End of global settings.  Start loading packages, etc.

;; Start the server to enable emacsclient 
;; (only under X, so skip if on the console).
(cond (window-system 
      ; Make server available for emacsclient.
      (server-start)
      ; Let's try gnuserv instead.
      ;(autoload 'gnuserv-start "gnuserv-comp")
      ;(require 'gnuserv)
      ;(gnuserv-start)
      (message "emacs server started")

      ; Cause emacsclient to bring up files in a new window.
      ; Otherwise you have to hunt for open emacsen.
      (defun my-make-frame (&optional parameters)
	"Create a new frame, displaying the current buffer, and
        switch to the new frame"
	(interactive)
	(make-frame parameters)
	(other-frame 1))
      (defun my-server-visit-hook ()
	;my-make-frame keeps old frame from getting copy 
	; of buffer as well.
	(my-make-frame)
	; Force fontification
	(font-lock-fontify-buffer))
      (setq server-visit-hook 'my-server-visit-hook)
      (defun my-server-done-hook ()
	; Clean up by removing frame.
	(delete-frame))
      (setq server-done-hook 'my-server-done-hook)
)) ;end window-system cond.

;; Get rid of that annoying prompt that requires one to type
;; in Y-E-S and then press the friggin enter key to confirm.
(defun yes-or-no-p (PROMPT)
  (beep)
  (y-or-n-p PROMPT))

;; Handy little redo function (redo.el)
;; http://www.wonderworks.com/
(require 'redo)
(global-set-key [(control x)(control r)] 'redo) ;consistent with my undo.

;; Support for marking a rectangle of text with highlighting (rect-mark.el).
; ftp://ls6-ftp.cs.uni-dortmund.de/pub/src/emacs/ 
; I couldn't get my rm-set-mark keybinding  to work except with read-kbd-macro!
(global-set-key (read-kbd-macro "C-x r C-SPC") 'rm-set-mark)
(global-set-key "\C-xr\C-x" 'rm-exchange-point-and-mark)
(global-set-key "\C-xr\C-w" 'rm-kill-region)
(global-set-key "\C-xr\M-w" 'rm-kill-ring-save)
;<shift>-<mouse button 1> now does a rectangular mark.
(global-set-key [(shift button1)] 'rm-mouse-drag-region)
(autoload 'rm-set-mark "rect-mark"
  "Set mark for rectangle." t)
(autoload 'rm-exchange-point-and-mark "rect-mark"
  "Exchange point and mark for rectangle." t)
(autoload 'rm-kill-region "rect-mark"
  "Kill a rectangular region and save it in the kill ring." t)
(autoload 'rm-kill-ring-save "rect-mark"
  "Copy a rectangular region to the kill ring." t)
(autoload 'rm-mouse-drag-region "rect-mark"
  "Drag out a rectangular region with the mouse." t)


;; Wrapper for catdoc to deal with word files (catdoc.el)
;; http://www.tardis.ed.ac.uk/~skx/win/catdoc.el
(require 'catdoc)


;; Some dired extensions (dired-a.el)
;; http://www.deja.com/getdoc.xp?AN=522707065&fmt=raw
(require 'dired-a)


;;; Emacs/W3 Configuration
(condition-case () (require 'w3-auto "w3-auto") (error nil))


;; mutt mail message editing mode (post.el)
;; http://astro.utoronto.ca/~reid/mutt/
(require 'post)

;; Add an informative message when editing mail messages under post.el.
(defadvice server-process-filter (after post-mode-message first activate)
  "If the buffer is in post mode, overwrite the server-edit
   message with a post-save-current-buffer-and-exit message."
  (if (eq major-mode 'post-mode)
      (message
       (substitute-command-keys 
"Type \\[describe-mode] for help composing; \\[post-save-current-buffer-and-exit] when done."))))
 ;This is also needed to see the magic message.  Set to a higher
 ;number if you have a faster computer or read slower than me.
'(font-lock-verbose 1000)
(add-hook 'server-switch-hook 
	  (function (lambda()
		      (cond ((string-match "Post" mode-name)
			     (post-goto-body))))))

;; Customize post mode a bit.
(defun my-post-mode-hook ()
  ; Turn on abbrev mode
  ; (sort of a simple auto-correct for common mispellings).
  (setq abbrev-mode t)
  (read-abbrev-file (concat my-emacs-dir ".post_abbrev_defs"))
  (setq save-abbrevs t)
  ; Add a key binding for ispell-buffer.
  (local-set-key [(control c)(control i)] 'ispell-buffer))
(add-hook 'post-mode-hook 'my-post-mode-hook)


;; Make sure we have sgml and xml modes (psgml.el)
(autoload 'sgml-mode "psgml" "Major mode to edit SGML files." t)
(autoload 'xml-mode "psgml" "Major mode to edit XML files." t)
(setq sgml-set-face t)
(setq sgml-indent-step t)
(setq sgml-live-element-indicator t)
;; Recognize Lutris Enhydra doml files as xml.  This doesn't work
;; very well because xml-mode has problems reading the doml dtd.
(setq auto-mode-alist (cons '("\\.doml$" . xml-mode) auto-mode-alist))


;; Enable dictionary mode (dictionary.el).  With this, you can do a
;;  M-x dictionary-search and search a number of free
;;  dictionaries on the web for a definition.  Works great.
;; http://www.in-berlin.de/User/myrkr/dictionary.html
(autoload 'dictionary-search "dictionary"
  "Ask for a word and search it in all dictionaries" t)
(autoload 'dictionary-match-words "dictionary"
  "Ask for a word and search all matching words in the dictionaries" t)
(autoload 'dictionary "dictionary"
  "Create a new dictionary buffer" t)
;; Assign keyboard shortcuts C-c s and C-c m.
(global-set-key "\C-cs" 'dictionary-search)
(global-set-key "\C-cm" 'dictionary-match-words)


;;; Java stuff.
;; Current versions of the JDE require semantic bovinator and speedbar.
;; http://www.ultranet.com/~zappo/
(setq load-path (cons 
		 (concat my-emacs-dir "semantic-1.1" ) load-path))

(setq load-path (cons
		 (concat my-emacs-dir "speedbar-0.11") load-path))


;; Load up the Java Dev Environment
;; http://sunsite.auc.dk/jde/ 
(setq load-path (nconc (list (concat my-emacs-dir "jde-2.1.7/lisp" )) load-path))
;(pushnew (concat my-emacs-dir "jde-2.1.7/lisp") load-path :test 'equal)

(require 'jde)
;; Customize jde behavior.
(defun my-jde-mode-hook () 
  ;; Auto-indent on <enter>
  (local-set-key [(control m)] 'newline-and-indent)
  (message "My JDE customizations loaded"))
(add-hook 'jde-mode-hook 'my-jde-mode-hook)

;; Load jdok for javadoc comment templates.
;;  Very cool stuff - make comment writing much easier.
(require 'jdok)                          ;bound to C-cj


;; Enable html-helper-mode for editing html files.
;; http://www.gest.unipd.it/~saint/hth.html 
;; Set some defaults.
(autoload 'html-helper-mode "html-helper-mode" "Yay HTML" t)
(setq auto-mode-alist (cons '("\\.html$" . html-helper-mode) auto-mode-alist))
(setq tempo-interactive t)
(setq html-helper-address-string 
      (concat "<a href=\"mailto:" user-mail-address "\">" user-full-name "</a>" ))
(setq html-helper-do-write-file-hooks t)
(setq html-helper-build-new-buffer t)


;; Load the auto-save.el package, which lets you put all of your autosave
;; files in one place, instead of scattering them around the file system.
;; ftp://archive.cis.ohio-state.edu/pub/emacs-lisp/misc/auto-save.el.Z
(setq auto-save-directory 
      (expand-file-name (concat my-emacs-dir "autosave"))
      auto-save-directory-fallback auto-save-directory
      auto-save-hash-p nil
      efs-auto-save t
      efs-auto-save-remotely nil
      ;; now that we have auto-save-timeout, let's crank this up
      ;; for better interactive response.
      auto-save-interval 2000
      )
;; We load this afterwards because it checks to make sure the
;; auto-save-directory exists (creating it if not) when it's loaded.
(require 'auto-save)


;; Tell cc-mode not to check for old-style (K&R) function declarations.
;; This speeds up indenting a lot.
(add-hook 'c-mode-common-hook 
	  (function (lambda ()
		      (setq c-recognize-knr-p nil))))


;; Settings only applicable under X
(cond (window-system

  ;; Font-Lock is a syntax-highlighting package.
    
  (setq font-lock-use-default-fonts nil)
  (setq font-lock-use-default-colors nil)
  
  (require 'font-lock)

  ;; Mess around with the faces a bit.  Note that you have
  ;; to change the font-lock-use-default-* variables *before*
  ;; loading font-lock, and wait till *after* loading font-lock
  ;; to customize the faces.
  
  ;; string face is green
  (set-face-foreground 'font-lock-string-face "yellow")
  
  ;; function names are green
  (set-face-foreground 'font-lock-function-name-face "green")
  
  ;; comment face
  (copy-face 'font-lock-comment-face 'font-lock-doc-string-face)
  (set-face-foreground 'font-lock-comment-face "green2")
  
  ;; misc. faces
  (copy-face 'italic 'font-lock-type-face)
  (set-face-foreground 'font-lock-keyword-face "orchid")


  ;;; fast-lock is a package which speeds up the highlighting of files
  ;;; by saving information about a font-locked buffer to a file and
  ;;; loading that information when the file is loaded again.
  ;;;
  ;;; Normally fast-lock puts the cache file (the filename appended with
  ;;; .flc) in the same directory as the file it caches.  You can
  ;;; specify an alternate directory to use by setting the variable
  ;;; fast-lock-cache-directories.
  
  (add-hook 'font-lock-mode-hook 'turn-on-fast-lock)
  (setq fast-lock-cache-directories 
	(list (concat my-emacs-dir "fastlock")))

  ;; I'm not even going to touch these.
  (custom-set-variables)
  (custom-set-faces
   '(custom-set-face ((((class color)) (:foreground "green" :background "black")) (t (:italic t))))
   '(primary-selection ((t (:background "blue"))) t)
   '(secondary-selection ((t (:background "blue"))) t)
   '(widget-field-face ((((class color grayscale)) (:background "blue")) (((class color grayscale) (background dark)) (:background "black")) (t (:italic t))))
  
   '(dired-face-permissions ((t nil)))
  
   '(font-lock-reference-face ((t (:foreground "cyan"))) t)
   '(font-lock-preprocessor-face ((t (:foreground "green"))) t)
   '(font-lock-variable-name-face ((t (:foreground "white"))) t)
   '(font-lock-type-face ((t (:foreground "yellow"))) t)
   '(font-lock-keyword-face ((t (:foreground "orchid"))) t)
  
   '(modeline-buffer-id ((t (:foreground "navajowhite" :background "black"))) t)
   '(modeline-mousable-minor-mode ((t (:foreground "green"))) t)
   '(bold-italic ((t (:italic t))) t)
   '(list-mode-item-selected ((t nil)) t)
  
   '(isearch ((t (:background "royalblue"))) t)
   '(highlight ((t (:background "blue"))) t)
   '(modeline ((t (:foreground "yellow" :background "black"))) t)
   '(zmacs-region ((t (:background "royalblue"))) t)
   '(dired-face-marked ((t (:background "royalblue")))))

  (custom-set-faces
   '(list-mode-item-selected ((t nil)) t)
   '(modeline-mousable-minor-mode ((t (:foreground "green"))) t)
   '(dired-face-marked ((t (:background "royalblue"))))
   '(font-lock-reference-face ((t (:foreground "cyan"))) t)
   '(custom-set-face ((((class color)) (:foreground "green" :background "black")) (t (:italic t))))
   '(font-lock-keyword-face ((t (:foreground "orchid"))))
   '(isearch ((t (:background "royalblue"))) t)
   '(primary-selection ((t (:background "blue"))) t)
   '(widget-field-face ((((class color grayscale)) (:background "blue")) (((class color grayscale) (background dark)) (:background "black")) (t (:italic t))))
   '(dired-face-permissions ((t nil)))
   '(modeline-buffer-id ((t (:foreground "navajowhite" :background "black"))) t)
   '(font-lock-preprocessor-face ((t (:foreground "green"))) t)
   '(zmacs-region ((t (:background "royalblue"))) t)
   '(font-lock-type-face ((t (:foreground "yellow"))))
   '(modeline ((t (:foreground "yellow" :background "black"))))
   '(highlight ((t (:background "blue"))))
   '(font-lock-variable-name-face ((t (:foreground "white"))))
   '(bold-italic ((t (:italic t))))
   '(secondary-selection ((t (:background "royal blue"))))
   '(makefile-space-face ((((class color)) (:background "purple")))))

)) ;end window-system cond.


(custom-set-variables
 '(jde-bug-jdk-directory "/usr/local/jdk1.2.2")
 '(jde-db-source-directories (quote ("/home/philip/java/" "/home/philip/projects/BookShelf/bookShelf/presentation" "/home/philip/projects/BookShelf/bookShelf/presentation/bookMgmt")))
 '(jde-db-debugger (quote ("JDEbug" "jdb" . "Executable")))
 '(jde-global-classpath (quote ("/usr/local/jdk1.2.2/lib/tools.jar" "/usr/localjswdk-1.0.1/lib/servlet.jar" "/usr/local/enhydra3.0.1/lib/enhydra.jar" )))
 '(jdok-version-tag-template (quote ("* @version $Revision: 1.7 $")))
 '(jde-enable-abbrev-mode t)
 '(jde-bug-jpda-directory "/usr/local/jdk1.2.2/")
 '(jdok-author-tag-template (quote ("* @author $Author: philip $"))))


;;; End of my .emacs

;; $Log: .emacs.el,v $
;; Revision 1.7  2000/07/12 22:52:08  philip
;; Cleaned up comments, added links to locations of packages I use.
;;
;; Revision 1.6  2000/07/12 19:41:31  philip
;; Added \eOH and \eOF for home and end keys, as these weren't mapped
;; properly on a remote xterm.
;;
;; Revision 1.5  2000/07/12 18:58:21  philip
;; Ok, so I couldn't do the keyboard maps like I thought for some
;; multi-char sequences, so I switched thos eback to standard emacs.
;; Also I discovered that pushnew doesn't work, so went back to setq.
;;
;; Revision 1.4  2000/07/11 22:59:40  philip
;; Converted to xemacs-friendly key specs.  Fixed user variables.  Switched to pushnew for
;; loadpath to avoid dups.
;;
;; Revision 1.3  2000/07/11 18:46:45  philip
;; Added RCS log tag.
;;
